@@ -23,11 +23,11 @@ from os.path import exists
 
 APP = 'gvb'
 if exists('locale'):
-	DIR = 'locale'
+    DIR = 'locale'
 else:
-	DIR = '/usr/share/locale'
+    DIR = '/usr/share/locale'
 
-print "Using", DIR
+print("Using", DIR)
 
 locale.setlocale(locale.LC_ALL, '')
 gettext.bindtextdomain(APP, DIR)
